@@ -861,9 +861,6 @@ pg_background_worker_main(Datum main_arg)
 	RestoreGUCState(gucstate);
 	CommitTransactionCommand();
 
-	/* Restore user ID and security context. */
-	SetUserIdAndSecContext(fdata->current_user_id, fdata->sec_context);
-
 	/* Prepare to execute the query. */
 	SetCurrentStatementStartTimestamp();
 	debug_query_string = sql;
@@ -874,6 +871,9 @@ pg_background_worker_main(Datum main_arg)
 	else
 		disable_timeout(STATEMENT_TIMEOUT, false);
 
+	/* Restore user ID and security context. */
+	SetUserIdAndSecContext(fdata->current_user_id, fdata->sec_context);
+
 	/* Execute the query. */
 	execute_sql_string(sql);
 
@@ -1033,11 +1033,7 @@ execute_sql_string(const char *sql)
 		portal = CreatePortal("", true, true);
 		/* Don't display the portal in pg_cursors */
 		portal->visible = false;
-#if PG_VERSION_NUM < 180000
-                PortalDefineQuery(portal, NULL, sql, commandTag, plantree_list, NULL);
-#else
-                PortalDefineQuery(portal, NULL, sql, commandTag, plantree_list, NULL, NULL);
-#endif
+        PortalDefineQuery(portal, NULL, sql, commandTag, plantree_list, NULL);
 		PortalStart(portal, NULL, 0, InvalidSnapshot);
 		PortalSetResultFormat(portal, 1, &format);	/* binary format */
 
